@@ -177,11 +177,10 @@ def unpack_key( ) :
 
     ########################################################
 
-
-    if( ( key_parts[ 0 ] != "*" ) and ( len(key_parts[ 0 ]) == 67) ) :
-        #set_key_alt( "endpoint/token" , key_parts[ 0 ] )
-        set_key( "endpoint/token" , key_parts[ 0 ] )
-
+    #if( ( key_parts[ 0 ] != "*" ) and ( len( key_parts[ 0 ] ) == 67 ) ) :
+    #    #set_key_alt( "endpoint/token" , key_parts[ 0 ] )
+    #   set_key( "endpoint/token" , key_parts[ 0 ] )
+    set_key( "endpoint/token" , key_parts[ 0 ] )
 
     ########################################################
 
