@@ -96,7 +96,7 @@ def flush( ) :
 def init_data( ) :
 # FIXME TODO add host environment vars e.g. hostname/machine id etc.
     sys_create( "ver_db" , "1.0" )
-    #sys_create( "ver_sapi" , s_config.get_key( "/config/version" ) )
+    sys_create( "ver_sapi" , s_config.get_key( "/config/version" ) )
     sys_create( "serial" , "ODS042e1919c5bd8f41cd8e1a2b8e455dd8f6fb00df0c3916d1137047a7aafc4c42" )
     sys_create( "motto" , "HORAS NON NUMERO NISI SERENAS" )
     sys_create( "rev" , 1 )
@@ -108,9 +108,9 @@ def init_data( ) :
     sys_create( "platform_uname" , platform.uname( ) )
     sys_create( "python_version" , platform.python_version( ) )
 
-    sys_create( "config_dbpassthru" , s_config.get_key("db/passthru") )
+    sys_create( "config_dbpassthru" , s_config.get_key( "db/passthru" ) )
 
-    s_log.write(sys_read("time_isoformat"))
+    #s_log.write(sys_read("time_isoformat"))
 
 def fdelete( ) :
 
