@@ -114,7 +114,7 @@ def check_connectivity( ) :
 
 #####################################################################
 
-def job_request( ) :
+def job_request( params = { } ) :
 
     #if( not s_util.ready( ) ) :
     #    s_log.write( "NOT READY" )
@@ -127,6 +127,9 @@ def job_request( ) :
     #####################################################################
 
     headers = { "X-Omni-Action": "job_request" }
+    headers["X-Omni-Params"]=s_util.json_encode(params)
+
+    s_log.write(headers)
 
     res = get_request_response( headers , payload )
 
