@@ -184,7 +184,7 @@ def uptime_lap( ) :
 
 
 def printexit( msg ) :
-    print( msg )
+    print( "PREXIT: " + msg )
     sys.exit( )
 
 
