@@ -64,7 +64,7 @@ def log_lap( ) :
 def heartbeat( t = 60 ) :
     return( s_util.heartbeat( t ) )
 
-def server( runner ) :
+def server( runner , debug_errorprexit = False ) :
 
     s_log.write( "SERVER START" )
 
@@ -81,8 +81,10 @@ def server( runner ) :
         except Exception as e :
             s_log.write( "Exception job_get" )
             s_util.printexception( )
-            #continue
-            prexit( "EXCEPTION job_get" )
+            # FIXME TODO add flags to server
+            if debug_errorprexit : prexit( "EXCEPTION job_get" )
+            print( "Exception job_get" )
+            continue
             #sys.exit( 99 )
 
         #####################################################
@@ -91,8 +93,9 @@ def server( runner ) :
 
             #s_config.get_key( "endpoint/url" ) 
             s_log.write( "ERROR False job_get" )
-            #continue
-            prexit( "False job_get" )
+            if debug_errorprexit : prexit( "ERROR False job_get" )
+            print( "ERROR False job_get" )
+            continue
 
         if flag_jobget == None :
             continue
@@ -192,7 +195,7 @@ def run( params = { } , wait_timeout = 60 ) :
 
     #####################################################################
 
-    if not s_net.job_request( ) :
+    if not s_net.job_request( params ) :
         s_log.write( "false job_request" )
         return( False )
 
